## Yaml-Pyconf
A simple utility for combining yaml files
and dotenv files into a very basic python config object, 
with config options represented as key-value pairs.

## Current Status:
As of the time the most recent commit, this is 
an afternoon's work from start to finish. Use at 
your own risk. Feel free to report issues or
contribute.